from django.contrib import admin
from .models import LogEntry

class LogEntryAdmin(admin.ModelAdmin):
    list_display = ('message', 'level', 'logged_at', 'tags')
    readonly_fields = ('level', 'message', 'logged_at', 'tags')
    list_filter = ('level', )
    search_fields = ('message', )

    def tags(self, obj):
        tags = ''
        for t in obj.tags.all():
            tags += '{}, '.format(t.tag)

        return tags[:-2]

admin.site.register(LogEntry, LogEntryAdmin)




from django.db import models


class LogEntry(models.Model):
    level       = models.CharField(max_length=16)
    message     = models.TextField()
    logged_at   = models.DateTimeField(auto_now_add=True)


class LogTag(models.Model):
    tag         = models.CharField(max_length=64)
    log_entries = models.ManyToManyField(LogEntry, related_name='tags')




from setuptools import setup

setup(name='django-lumberjack',
      version='0.1',
      description='Simple logging. Stored in database, accessed in Django admin.',
      url='http://github.com/lander2k2/django-lumberjack',
      author='Richard Lander',
      author_email='lander2k2@gmail.com',
      license='MIT',
      packages=['lumberjack'],
      install_requires=['django>=1.4,<1.8'],
      zip_safe=False)

